import math


def distribute(whole, cnt):
    remains = whole
    progress = 0

    if whole >= cnt:
        while remains > 0:
            current_portion = math.ceil(remains / cnt)
            progress += current_portion
            remains -= current_portion

            cnt -= 1
            yield (progress, current_portion, remains, cnt)

    else:
        while cnt > 0:
            repeat = math.floor(cnt / remains)

            current_portion = 1
            progress += current_portion
            remains -= current_portion

            while repeat > 0:
                repeat -= 1
                cnt -= 1
                yield (progress, current_portion, remains, cnt)



# -*- coding: utf-8 -*-

import os


from distutils.core import setup
setup(
  #name='distrib',  # testpypi
  name='distrib_val',  # pypi

  packages=['distrib'],
  version='0.1.0',
  description='Распределитель числового значения.',
  author='Аббас Гусенов',
  author_email='gusenov@live.ru',
  license='MIT',
  url='https://github.com/gusenov/distributor-of-numerical-value-py',
  download_url='https://github.com/gusenov/distributor-of-numerical-value-py/archive/v0.1.0.tar.gz',
  keywords='division',
  classifiers=[
      'License :: OSI Approved :: MIT License',
      'Programming Language :: Python',
      'Topic :: Scientific/Engineering :: Mathematics',
      'Topic :: Software Development :: Libraries :: Python Modules'
  ]
)
